#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MEANOF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MEANOF_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/meanof.hpp>

#endif
